summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/kofficepart/kopart_factory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/kofficepart/kopart_factory.cpp')
-rw-r--r--languages/cpp/app_templates/kofficepart/kopart_factory.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/languages/cpp/app_templates/kofficepart/kopart_factory.cpp b/languages/cpp/app_templates/kofficepart/kopart_factory.cpp
index 034e2fb3..d020ed5e 100644
--- a/languages/cpp/app_templates/kofficepart/kopart_factory.cpp
+++ b/languages/cpp/app_templates/kofficepart/kopart_factory.cpp
@@ -37,14 +37,14 @@ KAboutData* %{APPNAME}Factory::s_aboutData = 0L;
s_global = 0L;
}
-KParts::Part* %{APPNAME}Factory::createPartObject( TQWidget *tqparentWidget, const char *widgetName, TQObject* tqparent, const char* name, const char* classname, const TQStringList & )
+KParts::Part* %{APPNAME}Factory::createPartObject( TQWidget *parentWidget, const char *widgetName, TQObject* tqparent, const char* name, const char* classname, const TQStringList & )
{
// If classname is "KoDocument", our host is a koffice application
// otherwise, the host wants us as a simple part, so switch to readonly and single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
// tqparentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
%{APPNAME}Part *part = new %{APPNAME}Part( tqparentWidget, widgetName, tqparent, name, !bWantKoDocument );
if ( !bWantKoDocument )
part->setReadWrite( false );
@@ -37,14 +37,14 @@ KAboutData* %{APPNAME}Factory::s_aboutData = 0L;
// otherwise, the host wants us as a simple part, so switch to readonly and single view.
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
- // tqparentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
- %{APPNAME}Part *part = new %{APPNAME}Part( tqparentWidget, widgetName, tqparent, name, !bWantKoDocument );
+ // parentWidget and widgetName are used by KoDocument for the "readonly+singleView" case.
+ %{APPNAME}Part *part = new %{APPNAME}Part( parentWidget, widgetName, tqparent, name, !bWantKoDocument );
if ( !bWantKoDocument )
part->setReadWrite( false );